clacks_overhead

A man is not dead while his name is still spoken.

Silently commemorate people through the x-clacks-overhead HTTP header, inspired by the work of Terry Pratchett.

Values

pub fn commemorate(
  response: response.Response(a),
  names: List(String),
) -> response.Response(a)

Commemorate people of your choosing.

my_http_response
|> clacks_overhead.commemorate(["Chris Young"])
pub fn commemorate_terry(
  response: response.Response(a),
) -> response.Response(a)

Commemorate the late, great, Sir Terry Pratchett by prepending the the header x-clacks-overhead: GNU Terry Pratchett.

pub const header_name: String

The x-clacks-overhead header.

Header names are always lowercase in Gleam.

pub const terry_pratchett: String

Terry Pratchett’s name, should you want to add him to the list of people you wish to commemorate.

✨ Search Document